<?php
/**
 * LineDrawing functions and definitions
 *
 * @package LineDrawing
 */

 
 /**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 900;
}

if ( ! function_exists( 'linedrawing_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function linedrawing_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on LineDrawing, use a find and replace
	 * to change 'linedrawing' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'linedrawing', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'linedrawing' )
	) );

	// Enable support for Post Formats.
	add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );

	// Setup the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'linedrawing_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );

	// Enable support for HTML5 markup.
	add_theme_support( 'html5', array(
		'comment-list',
		'search-form',
		'comment-form',
		'gallery',
	) );
}
endif; // linedrawing_setup
add_action( 'after_setup_theme', 'linedrawing_setup' );

/**
 * Register widgetized area and update sidebar with default widgets.
 */
function linedrawing_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Above Menu', 'linedrawing' ),
		'id'            => 'before_nav',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Below Menu', 'linedrawing' ),
		'id'            => 'after_nav',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}
add_action( 'widgets_init', 'linedrawing_widgets_init' );

if (! function_exists( 'linedrawing_posted_on' ) ) :
/* Display metadata under post titles
*/
function linedrawing_posted_on() {
	
	//Display date that post was published
	if ( ! has_post_format( 'link' ) && 'post' == get_post_type() ) {
		linedrawing_entry_date();
	}
	
	//Display author of post	
	if ('post' == get_post_type() ) {
		printf('<span class="author vcard"><a class"url fn n" href="%1$s"
		title="%2$s" rel="author">%3$s</a></span>',
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			esc_attr( sprintf( __( 'Просмотреть все записи от %s', 'linedrawing' ), get_the_author() ) ),
			get_the_author()
		);
	}
	
	//Catagories
	$categories_list = get_the_category_list( __( ', ', 'linedrawing' ) );
	if ( $categories_list ) {
		echo '<span class="categories-links">' . $categories_list . '</span>';
	}	
}
endif; //linedrawing_posted_on

if ( ! function_exists( 'linedrawing_entry_date' ) ) :
/**
 * Print HTML with date information for current post.
 *
 * Create your own linedrawing_entry_date() to override in a child theme.
 *
 * @since Twenty Thirteen 1.0
 *
 * @param boolean $echo (optional) Whether to echo the date. Default true.
 * @return string The HTML-formatted post date.
 */
function linedrawing_entry_date( $echo = true ) {
	if ( has_post_format( array( 'chat', 'status' ) ) )
		$format_prefix = _x( '%1$s - %2$s', '1: post format name. 2: date', 'linedrawing' );
	else
		$format_prefix = '%2$s';

	$date = sprintf( '<span class="date"><a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a></span>',
		esc_url( get_permalink() ),
		esc_attr( sprintf( __( 'Постоянная ссылка на %s', 'linedrawing' ), the_title_attribute( 'echo=0' ) ) ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( sprintf( $format_prefix, get_post_format_string( get_post_format() ), get_the_date() ) )
	);

	if ( $echo )
		echo $date;

	return $date;
}
endif;

if ( ! function_exists( 'linedrawing_paging_nav' ) ) :
/**
* Post Navigation
*
*/
function linedrawing_paging_nav() {
	global $wp_query;
	
	//Don't print empty markup if there's only one page.
	if ( $wp_query->max_num_pages < 2 )
		return;
	?>
	<nav class="navigation paging-navigation" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Навигация', 'linedrawing' ); ?></h1>
		<div class="nav-links">

			<?php if ( get_next_posts_link() ) : ?>
			<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Предыдущие записи', 'linedrawing' ) ); ?></div>
			<?php endif; ?>

			<?php if ( get_previous_posts_link() ) : ?>
			<div class="nav-next"><?php previous_posts_link( __( 'Следующие записи <span class="meta-nav">&rarr;</span>', 'linedrawing' ) ); ?></div>
			<?php endif; ?>

		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif; //linedrawing_paging_nav

if ( ! function_exists( 'linedrawing_post_nav' ) ) :
/**
 * Display navigation to next/previous post when applicable.
*
*
* @return void
*/
function linedrawing_post_nav() {
	global $post;

	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous )
		return;
	?>
	<nav class="navigation post-navigation" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Навигация', 'linedrawing' ); ?></h1>
		<div class="nav-links">

			<?php previous_post_link( '%link', _x( '<span class="meta-nav">&larr;</span> %title', 'Предыдущие записи', 'linedrawing' ) ); ?>
			<?php next_post_link( '%link', _x( '%title <span class="meta-nav">&rarr;</span>', 'Следующие записи', 'linedrawing' ) ); ?>

		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

/**
* Add support for Vertical Featured Images
* Stolen from John Regan (http://johnregan3.wordpress.com)
*/
if ( ! function_exists( 'linedrawing_vertical_check' ) ) :
function linedrawing_vertical_check( $html, $post_id, $post_thumbnail_id, $size, $attr ) {
 
	$image_data = wp_get_attachment_image_src( $post_thumbnail_id , 'large' );
 
	//Get the image width and height from the data provided by wp_get_attachment_image_src()
	$width = $image_data[1];
	$height = $image_data[2];
 
	if ( $height > ($width * 1.5) ) {
		$html = str_replace( 'featured-image ', 'vertical-featured ', $html );
	}
	return $html;
}
endif;
 
add_filter( 'post_thumbnail_html', 'linedrawing_vertical_check', 10, 5 );

/**
 * Enqueue scripts and styles.
 */
function linedrawing_scripts() {
	wp_enqueue_script( 'jquery' );

	//Loads Genericons font
	wp_enqueue_style( 'genericons', get_template_directory_uri() . '/fonts/genericons/genericons.css' );
	
	wp_enqueue_style( 'linedrawing-style', get_stylesheet_uri() );

	wp_enqueue_script( 'linedrawing-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'linedrawing-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	wp_enqueue_script( 'linedrawing-styles', get_template_directory_uri() . '/js/linedrawing.js', array(), '20120206', true );
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'linedrawing_scripts' );



/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
